@@ -1,6 +1,6 @@
 package Proc::tored::Manager;
 # ABSTRACT: OO interface to creating a proctored service
-$Proc::tored::Manager::VERSION = '0.06';
+$Proc::tored::Manager::VERSION = '0.07';
 
 use strict;
 use warnings;
@@ -20,6 +20,7 @@ my $Directory = declare, as $NonEmptyStr, where { -d $_ && -w $_ };
 with 'Proc::tored::Role::Running';
 
 
+
 has dir => (
   is  => 'ro',
   isa => $Directory,
@@ -42,19 +43,28 @@ sub _build_term_file {
   return "$file";
 }
 
-
-has filepath => (
+has pid_file => (
   is  => 'lazy',
   isa => $NonEmptyStr,
-  init_arg => undef,
 );
 
-sub _build_filepath {
+sub _build_pid_file {
   my $self = shift;
   my $file = path($self->dir)->child($self->name . '.pid');
   return "$file";
 }
 
+has lock_file => (
+  is  => 'lazy',
+  isa => $NonEmptyStr,
+);
+
+sub _build_lock_file {
+  my $self = shift;
+  my $file = path($self->dir)->child($self->name . '.lock');
+  return "$file";
+}
+
 
 
 sub service {
@@ -75,7 +85,7 @@ sub service {
 
 sub read_pid {
   my $self = shift;
-  my $file = path($self->filepath);
+  my $file = path($self->pid_file);
   return 0 unless $file->is_file;
   my ($line) = $file->lines({count => 1, chomp => 1}) or return 0;
   my ($pid) = $line =~ /^(\d+)$/;
@@ -99,7 +109,7 @@ sub stop_running_process {
   my $pid = $self->running_pid || return 0;
   return $self->stop if $pid == $$;
 
-  if ($self->signal > 0) {
+  if ($self->signal) {
     if ($timeout) {
       while (kill(0, $pid) && $timeout > 0) {
         sleep $sleep;
@@ -115,17 +125,21 @@ sub stop_running_process {
 sub run_lock {
   my $self = shift;
   return if $self->running_pid;
+  my $pid = $$;
+  my $locked = $self->_lock;
 
-  my $file = path($self->filepath);
-
-  # Write pid to the pidfile
-  if ($self->with_lock(sub { $file->spew("$$\n") })) {
+  if ($locked) {
+    # Write pid to the pidfile
+    my $file = path($self->pid_file);
+    $file->spew("$pid\n");
     $self->start;
 
     # Create guard object that releases the pidfile once out of scope
     return guard {
-      $self->stop;
-      $file->append({truncate => 1});
+      if ($$ == $pid) {
+        $self->stop;
+        $file->append({truncate => 1});
+      }
     };
   }
 
@@ -133,26 +147,15 @@ sub run_lock {
 }
 
 #-------------------------------------------------------------------------------
-# Calls $code while holding the lock, unlocking afterward. Returns true when
-# the lock is achieved and $code is called.
-#-------------------------------------------------------------------------------
-sub with_lock {
-  my ($self, $code) = @_;
-  my $lock = $self->_lock or return;
-  $code->();
-  undef $lock;
-  return 1;
-}
-
-#-------------------------------------------------------------------------------
-# Creates a .lock file based on $self->filepath. While the file exists, the
+# Creates a .lock file based on $self->pid_file. While the file exists, the
 # lock is considered to be held. Returns a Guard that removes the file.
 #-------------------------------------------------------------------------------
 sub _lock {
   my $self = shift;
+  my $pid = $$;
 
   # Existing .lock file means another process came in ahead
-  my $lock = path($self->filepath . '.lock');
+  my $lock = path($self->lock_file);
   return if $lock->exists;
 
   my $locked = try {
@@ -168,7 +171,7 @@ sub _lock {
     };
 
   return unless $locked;
-  return guard { $self->_unlock };
+  return guard { $self->_unlock if $$ == $pid };
 }
 
 #-------------------------------------------------------------------------------
@@ -176,8 +179,7 @@ sub _lock {
 #-------------------------------------------------------------------------------
 sub _unlock {
   my $self = shift;
-  my $lock = path($self->filepath . '.lock');
-  try { $lock->remove }
+  try { path($self->lock_file)->remove }
   catch { carp "unable to remove lock file: $_" }
 }
 
@@ -195,7 +197,7 @@ Proc::tored::Manager - OO interface to creating a proctored service
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -237,23 +239,22 @@ file is to be found.
 
 =item term_file
 
-By default (and on supported platforms), posix signals are used to signal a
-managed process to voluntarily self-terminate. On non-compliant systems (e.g.
-MSWin32), a touch file is used instead. The path to this file is automatically
-constructed from L</name> in L</dir> unless manually specified.
+A touch file is used to signal a process to self-terminate. The path to this
+file is automatically constructed from L</name> in L</dir> unless manually
+specified.
 
-=item filepath
+=item lock_file
 
-Unless manually specified, the pid file's C<filepath> is constructed from
+Before writing the pid file, a lock is secured through the atomic creation of a
+lock file. If the file fails to be created (with O_EXCL), the lock fails.
+
+=item pid_file
+
+Unless manually specified, the pid file's C<pid_file> is constructed from
 L</name> in L</dir>.
 
 =back
 
-=head2 filepath
-
-Returns the file system path created by concatenating the values of C<dir> and
-C<name> that were passed to C<new>.
-
 =head2 is_running
 
 See L<Proc::tored::Role::Running/is_running>.
