@@ -1,6 +1,6 @@
 package Proc::tored::Role::Running;
 # ABSTRACT: add running state and signal handling to services
-$Proc::tored::Role::Running::VERSION = '0.06';
+$Proc::tored::Role::Running::VERSION = '0.07';
 use strict;
 use warnings;
 use Moo::Role;
@@ -53,7 +53,7 @@ sub start {
 sub stop { $_[0]->{is_started} = 0; return 1 }
 
 
-sub signal { shift->_path->touch }
+sub signal { $_[0]->_path->touch->assert(sub { $_->exists }) }
 
 1;
 
@@ -69,7 +69,7 @@ Proc::tored::Role::Running - add running state and signal handling to services
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -120,9 +120,7 @@ will return false.
 
 =head2 signal
 
-Signals the process to stop running. If L</term_file> is set, this is done by
-creating a touch file. Otherwise, the caller is required to specify the pid of
-the process being signalled.
+Signals the process to stop running by creating a touch file.
 
 =head1 AUTHOR
 
